summaryrefslogtreecommitdiffstats
path: root/konsole/konsole/TEmulation.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsole/konsole/TEmulation.cpp')
-rw-r--r--konsole/konsole/TEmulation.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/konsole/konsole/TEmulation.cpp b/konsole/konsole/TEmulation.cpp
index 7b7e1c5f4..939139d03 100644
--- a/konsole/konsole/TEmulation.cpp
+++ b/konsole/konsole/TEmulation.cpp
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
// process application tqunicode input to terminal
// this is a trivial scanner
{
c &= 0xff;
@@ -284,7 +284,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
scr->setHistCursor(scr->getHistLines());
if (!ev->text().isEmpty())
{ // A block of text
// Note that the text is proper tqunicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.
emit sndBlock(TQString(ev->text()).ascii(),ev->text().length());
@@ -299,7 +299,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
// Unblocking, Byte to Unicode translation --------------------------------- --
/*
- We are doing code conversion from locale to tqunicode first.
+ We are doing code conversion from locale to unicode first.
*/
void TEmulation::onRcvBlock(const char *s, int len)
@@ -345,7 +345,7 @@ void TEmulation::onRcvBlock(const char *s, int len)
if (r[j].category() == TQChar::Mark_NonSpacing)
scr->compose(r.mid(j,1));
else
- onRcvChar(r[j].tqunicode());
+ onRcvChar(r[j].unicode());
}
i = l;
}
@@ -392,7 +392,7 @@ void TEmulation::clearSelection() {
void TEmulation::copySelection() {
if (!connected) return;
TQString t = scr->getSelText(true);
- TQApplication::tqclipboard()->setText(t);
+ TQApplication::clipboard()->setText(t);
}
TQString TEmulation::getSelection() {
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
-// process application tqunicode input to terminal
+// process application unicode input to terminal
// this is a trivial scanner
{
@@ -284,7 +284,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
if (!ev->text().isEmpty())
{ // A block of text
- // Note that the text is proper tqunicode.
+ // Note that the text is proper unicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.